@@ -51,6 +51,26 @@ def lots():
 
     return json.dumps(result)
 
+@app.route('/repopull', methods=['POST'])
+def repo_pull():
+    '''
+    Pull the changes in the repository.
+    Expects { repoPath: ... } parameter in JSON.
+    '''
+    from cashiersync.executor import Executor
+
+    json = request.get_json()
+    repo_path = json['repoPath']
+
+    # Execute git pull and return all the console results.
+    try:
+        executor = Executor(app.logger)
+        output = executor.run("git pull", repo_path)
+    except Exception as e:
+        output = f'Error: {str(e)}'
+
+    return output
+
 @app.route('/securitydetails')
 def security_details():
     ''' Displays the security details (analysis) '''
